
Package: whalebuilder-dependency-helper
Section: misc
Priority: optional
Standards-Version: 3.9.2
Version: 1.0
Architecture: <%= @arch %>
Maintainer: Whalebuilder Dependency Helper
<% if @depends.length > 0 -%>
Depends: <%= @depends %>
<% end -%>
<% if @conflicts.length > 0 -%>
Conflicts: <%= @conflicts %>
<% end -%>
Description: Installs dependencies needed to build <%= @dsc.package %> <%= @dsc.version %>
